==> zio-aws-rekognition_2.12-5.17.124.2-sources.jar: zio/aws/rekognition/model/KnownGender.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class KnownGender(
    `type`: Option[zio.aws.rekognition.model.KnownGenderType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.KnownGender = {
    import KnownGender.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.KnownGender
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.KnownGender.ReadOnly =
    zio.aws.rekognition.model.KnownGender.wrap(buildAwsValue())
}
object KnownGender {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.KnownGender
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.KnownGender =
      zio.aws.rekognition.model.KnownGender(`type`.map(value => value))
    def `type`: Option[zio.aws.rekognition.model.KnownGenderType]
    def getType: ZIO[Any, AwsError, zio.aws.rekognition.model.KnownGenderType] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.KnownGender
  ) extends zio.aws.rekognition.model.KnownGender.ReadOnly {
    override val `type`: Option[zio.aws.rekognition.model.KnownGenderType] =
      scala
        .Option(impl.`type`())
        .map(value => zio.aws.rekognition.model.KnownGenderType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.KnownGender
  ): zio.aws.rekognition.model.KnownGender.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.20.7.2-sources.jar: zio/aws/rekognition/model/KnownGender.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class KnownGender(
    `type`: Optional[zio.aws.rekognition.model.KnownGenderType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.KnownGender = {
    import KnownGender.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.KnownGender
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.KnownGender.ReadOnly =
    zio.aws.rekognition.model.KnownGender.wrap(buildAwsValue())
}
object KnownGender {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.KnownGender
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.KnownGender =
      zio.aws.rekognition.model.KnownGender(`type`.map(value => value))
    def `type`: Optional[zio.aws.rekognition.model.KnownGenderType]
    def getType: ZIO[Any, AwsError, zio.aws.rekognition.model.KnownGenderType] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.KnownGender
  ) extends zio.aws.rekognition.model.KnownGender.ReadOnly {
    override val `type`: Optional[zio.aws.rekognition.model.KnownGenderType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.rekognition.model.KnownGenderType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.KnownGender
  ): zio.aws.rekognition.model.KnownGender.ReadOnly = new Wrapper(impl)
}
